@@ -24,8 +24,27 @@ grid_file = "case14_test.json"
 case14_test_CASEFILE = os.path.join(dat_dir, case_dir, grid_file)
 case14_test_CHRONICSPATH = os.path.join(dat_dir, case_dir, "chronics")
 
-case14_test_TH_LIM = np.array([   352.8251645 ,    352.8251645 , 183197.68156979, 183197.68156979,
-                                   183197.68156979,  12213.17877132, 183197.68156979,    352.8251645,
-                                      352.8251645 ,    352.8251645 ,    352.8251645 ,    352.8251645,
-                                   183197.68156979, 183197.68156979, 183197.68156979,    352.8251645,
-                                      352.8251645 ,    352.8251645 ,   2721.79412618,   2721.79412618])
+case14_test_TH_LIM = np.array(
+    [
+        352.8251645,
+        352.8251645,
+        183197.68156979,
+        183197.68156979,
+        183197.68156979,
+        12213.17877132,
+        183197.68156979,
+        352.8251645,
+        352.8251645,
+        352.8251645,
+        352.8251645,
+        352.8251645,
+        183197.68156979,
+        183197.68156979,
+        183197.68156979,
+        352.8251645,
+        352.8251645,
+        352.8251645,
+        2721.79412618,
+        2721.79412618,
+    ]
+)
