@@ -101,6 +101,7 @@ class RandomObject(object):
         # NB for fully reproducible expriment you have to have called "np.random.seed" before using this method.
 
     """
+
     def __init__(self):
         self.space_prng = np.random.RandomState()
         self.seed_used = None
@@ -130,7 +131,7 @@ class RandomObject(object):
         if self.seed_used is not None:
             # in this case i have specific seed set. So i force the seed to be deterministic.
             self.space_prng.seed(seed=self.seed_used)
-        return self.seed_used,
+        return (self.seed_used,)
 
     def _custom_deepcopy_for_copy(self, new_obj):
         # RandomObject
