@@ -6,13 +6,10 @@
 # SPDX-License-Identifier: MPL-2.0
 # This file is part of Grid2Op, Grid2Op a testbed platform to model sequential decision making in power systems.
 
-
 import warnings
 import unittest
 import grid2op
-import numpy as np
 
-from grid2op.Space import GridObjects
 from grid2op.Action.PowerlineSetAction import PowerlineSetAction
 from grid2op.Action.PlayableAction import PlayableAction
 from grid2op.Observation.completeObservation import CompleteObservation
@@ -28,9 +25,9 @@ class TestL2RPNNEURIPS2020_Track1(unittest.TestCase):
     def setUp(self) -> None:
         with warnings.catch_warnings():
             warnings.filterwarnings("ignore")
-            self.env = grid2op.make("l2rpn_neurips_2020_track1",
-                                    test=True)
+            self.env = grid2op.make("l2rpn_neurips_2020_track1", test=True)
             self.env.seed(0)
+            _ = self.env.reset()
 
     def test_elements(self):
         assert self.env.n_sub == 36
@@ -45,12 +42,14 @@ class TestL2RPNNEURIPS2020_Track1(unittest.TestCase):
 
     def test_action_space(self):
         assert issubclass(self.env.action_space.subtype, PlayableAction)
-        assert self.env.action_space.n == 494
+        assert self.env.action_space.n == 494, f"{self.env.action_space.n} instead of 494"
 
     def test_observation_space(self):
         assert issubclass(self.env.observation_space.subtype, CompleteObservation)
-        assert self.env.observation_space.n == 1332 + 4 + 24 + 2 + 1, f"obs space size is {self.env.observation_space.n}," \
-                                                                      f"should be {1332 + 4 + 24 + 2 + 1}"
+        size_th = 1266
+        assert self.env.observation_space.n == size_th, (
+            f"obs space size is {self.env.observation_space.n}, should be {size_th}"
+        )
 
     def test_random_action(self):
         """test i can perform some step (random)"""
@@ -60,17 +59,19 @@ class TestL2RPNNEURIPS2020_Track1(unittest.TestCase):
             obs, reward, done, info = self.env.step(act)
             if done:
                 break
-        assert i >= 1, "could not perform the random action test because it games over first time step. " \
-                       "Please fix the test and try again"
+        assert i >= 1, (
+            "could not perform the random action test because it games over first time step. "
+            "Please fix the test and try again"
+        )
 
 
 class TestL2RPNICAPS2021(unittest.TestCase):
     def setUp(self) -> None:
         with warnings.catch_warnings():
             warnings.filterwarnings("ignore")
-            self.env = grid2op.make("l2rpn_icaps_2021",
-                                    test=True)
+            self.env = grid2op.make("l2rpn_icaps_2021", test=True)
             self.env.seed(0)
+            _ = self.env.reset()
 
     def test_elements(self):
         assert self.env.n_sub == 36
@@ -86,14 +87,18 @@ class TestL2RPNICAPS2021(unittest.TestCase):
 
     def test_action_space(self):
         assert issubclass(self.env.action_space.subtype, PlayableAction)
-        assert self.env.action_space.n == 519, f"act space size is {self.env.action_space.n}," \
-                                               f"should be {519}"
+        assert self.env.action_space.n == 519, (
+            f"act space size is {self.env.action_space.n}, should be {519}"
+        )
 
     def test_observation_space(self):
         assert issubclass(self.env.observation_space.subtype, CompleteObservation)
-        assert self.env.observation_space.n == 1332 + 4 + 24 + 3 + 2 +1, f"obs space size is " \
-                                                                      f"{self.env.observation_space.n}," \
-                                                                      f"should be {1366}"
+        size_th = 1363
+        assert self.env.observation_space.n == size_th, (
+            f"obs space size is "
+            f"{self.env.observation_space.n}, "
+            f"should be {size_th}"
+        )
 
     def test_random_action(self):
         """test i can perform some step (random)"""
@@ -103,17 +108,19 @@ class TestL2RPNICAPS2021(unittest.TestCase):
             obs, reward, done, info = self.env.step(act)
             if done:
                 break
-        assert i >= 1, "could not perform the random action test because it games over first time step. " \
-                       "Please fix the test and try again"
+        assert i >= 1, (
+            "could not perform the random action test because it games over first time step. "
+            "Please fix the test and try again"
+        )
 
 
 class TestL2RPNNEURIPS2020_Track2(unittest.TestCase):
     def setUp(self) -> None:
         with warnings.catch_warnings():
             warnings.filterwarnings("ignore")
-            self.env = grid2op.make("l2rpn_neurips_2020_track2",
-                                    test=True)
-            self.env.seed(0)
+            self.env = grid2op.make("l2rpn_neurips_2020_track2", test=True)
+            self.env.seed(2)  # 0 or 1 breaks the test `test_random_action`
+            _ = self.env.reset()
 
     def test_elements(self):
         assert self.env.n_sub == 118
@@ -128,12 +135,14 @@ class TestL2RPNNEURIPS2020_Track2(unittest.TestCase):
 
     def test_action_space(self):
         assert issubclass(self.env.action_space.subtype, PlayableAction)
-        assert self.env.action_space.n == 1500
+        assert self.env.action_space.n == 1500, f"{self.env.action_space.n} instead of 1500"
 
     def test_observation_space(self):
         assert issubclass(self.env.observation_space.subtype, CompleteObservation)
-        assert self.env.observation_space.n == 4054 + 4 + 56 + 2 + 1, f"obs space size is {self.env.observation_space.n}," \
-                                                                      f"should be {4117}"
+        size_th = 3868
+        assert self.env.observation_space.n == size_th, (
+            f"obs space size is {self.env.observation_space.n}, should be {size_th}"
+        )
 
     def test_random_action(self):
         """test i can perform some step (random)"""
@@ -143,17 +152,19 @@ class TestL2RPNNEURIPS2020_Track2(unittest.TestCase):
             obs, reward, done, info = self.env.step(act)
             if done:
                 break
-        assert i >= 1, "could not perform the random action test because it games over first time step. " \
-                       "Please fix the test and try again"
+        assert i >= 1, (
+            "could not perform the random action test because it games over first 10 steps. "
+            "Please fix the test and try again"
+        )
 
 
 class TestL2RPN_CASE14_SANDBOX(unittest.TestCase):
     def setUp(self) -> None:
         with warnings.catch_warnings():
             warnings.filterwarnings("ignore")
-            self.env = grid2op.make("l2rpn_case14_sandbox",
-                                    test=True)
+            self.env = grid2op.make("l2rpn_case14_sandbox", test=True)
             self.env.seed(42)
+            _ = self.env.reset()
 
     def test_elements(self):
         assert self.env.n_sub == 14
@@ -168,12 +179,14 @@ class TestL2RPN_CASE14_SANDBOX(unittest.TestCase):
 
     def test_action_space(self):
         assert issubclass(self.env.action_space.subtype, PlayableAction)
-        assert self.env.action_space.n == 160
+        assert self.env.action_space.n == 166, f"{self.env.action_space.n} instead of 166"
 
     def test_observation_space(self):
         assert issubclass(self.env.observation_space.subtype, CompleteObservation)
-        assert self.env.observation_space.n == 438 + 4 + 4 + 2 + 1, f"obs space size is {self.env.observation_space.n}," \
-                                                                    f"should be {438 + 4 + 4 + 2 + 1}"
+        size_th = 467
+        assert self.env.observation_space.n == size_th, (
+            f"obs space size is {self.env.observation_space.n}," f"should be {size_th}"
+        )
 
     def test_random_action(self):
         """test i can perform some step (random)"""
@@ -183,17 +196,19 @@ class TestL2RPN_CASE14_SANDBOX(unittest.TestCase):
             obs, reward, done, info = self.env.step(act)
             if done:
                 break
-        assert i >= 1, "could not perform the random action test because it games over first time step. " \
-                       "Please fix the test and try again"
+        assert i >= 1, (
+            "could not perform the random action test because it games over first time step. "
+            "Please fix the test and try again"
+        )
 
 
 class TestEDUC_CASE14_REDISP(unittest.TestCase):
     def setUp(self) -> None:
         with warnings.catch_warnings():
             warnings.filterwarnings("ignore")
-            self.env = grid2op.make("educ_case14_redisp",
-                                    test=True)
+            self.env = grid2op.make("educ_case14_redisp", test=True)
             self.env.seed(0)
+            _ = self.env.reset()
 
     def test_elements(self):
         assert self.env.n_sub == 14
@@ -208,12 +223,14 @@ class TestEDUC_CASE14_REDISP(unittest.TestCase):
 
     def test_action_space(self):
         assert issubclass(self.env.action_space.subtype, PlayableAction)
-        assert self.env.action_space.n == 26
+        assert self.env.action_space.n == 26, f"{self.env.action_space.n} instead of 26"
 
     def test_observation_space(self):
         assert issubclass(self.env.observation_space.subtype, CompleteObservation)
-        assert self.env.observation_space.n == 438 + 4 + 4 + 2 + 1, f"obs space size is {self.env.observation_space.n}," \
-                                                                    f"should be {438 + 4 + 4 + 3}"
+        size_th = 467
+        assert self.env.observation_space.n == size_th, (
+            f"obs space size is {self.env.observation_space.n}," f"should be {size_th}"
+        )
 
     def test_random_action(self):
         """test i can perform some step (random)"""
@@ -223,17 +240,19 @@ class TestEDUC_CASE14_REDISP(unittest.TestCase):
             obs, reward, done, info = self.env.step(act)
             if done:
                 break
-        assert i >= 1, "could not perform the random action test because it games over first time step. " \
-                       "Please fix the test and try again"
+        assert i >= 1, (
+            "could not perform the random action test because it games over first time step. "
+            "Please fix the test and try again"
+        )
 
 
 class TestEDUC_STORAGE(unittest.TestCase):
     def setUp(self) -> None:
         with warnings.catch_warnings():
             warnings.filterwarnings("ignore")
-            self.env = grid2op.make("educ_case14_storage",
-                                    test=True)
+            self.env = grid2op.make("educ_case14_storage", test=True)
             self.env.seed(0)
+            _ = self.env.reset()
 
     def test_elements(self):
         assert self.env.n_sub == 14
@@ -248,12 +267,14 @@ class TestEDUC_STORAGE(unittest.TestCase):
 
     def test_action_space(self):
         assert issubclass(self.env.action_space.subtype, PlayableAction)
-        assert self.env.action_space.n == 28
+        assert self.env.action_space.n == 28, f"{self.env.action_space.n} instead of 28"
 
     def test_observation_space(self):
         assert issubclass(self.env.observation_space.subtype, CompleteObservation)
-        assert self.env.observation_space.n == 446 + 4 + 4 + 2 + 1, f"obs space size is {self.env.observation_space.n}," \
-                                                                    f"should be {446 + 4 + 4 + 3}"
+        size_th = 475
+        assert self.env.observation_space.n == size_th, (
+            f"obs space size is {self.env.observation_space.n}," f"should be {size_th}"
+        )
 
     def test_random_action(self):
         """test i can perform some step (random)"""
@@ -262,10 +283,11 @@ class TestEDUC_STORAGE(unittest.TestCase):
             act = self.env.action_space.sample()
             obs, reward, done, info = self.env.step(act)
             if done:
-                pdb.set_trace()
                 break
-        assert i >= 1, "could not perform the random action test because it games over first time step. " \
-                       "Please fix the test and try again"
+        assert i >= 1, (
+            "could not perform the random action test because it games over first time step. "
+            "Please fix the test and try again"
+        )
 
 
 if __name__ == "__main__":
