@@ -1,5 +1,6 @@
-__all__ = ["EpisodeStatistics", "ScoreL2RPN2020", "ScoreICAPS2021"]
+__all__ = ["EpisodeStatistics", "ScoreL2RPN2020", "ScoreICAPS2021", "ScoreL2RPN2022"]
 
 from grid2op.utils.underlying_statistics import EpisodeStatistics
 from grid2op.utils.l2rpn_2020_scores import ScoreL2RPN2020
 from grid2op.utils.icaps_2021_scores import ScoreICAPS2021
+from grid2op.utils.l2rpn_wcci_2022_scores import ScoreL2RPN2022
